@@ -379,7 +379,14 @@ def lines_to_msgs(lines: List[str]) -> List[List[str]]:
 def merge_attachments(media_new: Path, media_old: Path) -> None:
     for f in media_old.iterdir():
         if f.is_file():
-            shutil.copy2(f, media_new)
+            try:
+                shutil.copy2(f, media_new)
+            except shutil.SameFileError:
+                if log:
+                    secho(
+                        f"Skipped file {f} as duplicate found in new export directory!",
+                        fg=colors.RED,
+                    )
 
 
 def merge_chat(path_new: Path, path_old: Path) -> None:
@@ -486,7 +493,7 @@ def main(
 
     # Read sqlcipher key from Signal config file
     if source.is_file():
-        with open(source, "r") as conf:
+        with open(source) as conf:
             key = json.loads(conf.read())["key"]
     else:
         secho(f"Error: {source} not found in directory {src}")
@@ -502,6 +509,10 @@ def main(
             use_docker = True
 
     if use_docker:
+        secho(
+            "Using Docker to extract data, this may take a while the first time!",
+            fg=colors.BLUE,
+        )
         cmd = ["docker", "run", "--rm", f"--volume={src}:/Signal", docker_image]
         try:
             p = subprocess.run(cmd, capture_output=True, text=True, check=True)
@@ -512,18 +523,21 @@ def main(
             secho("Try running this from the command line:\ndocker run hello-world")
             raise Exit(1)
         except subprocess.CalledProcessError as e:
-            secho(f"Docker process failed, see logs below:\n{e}", gf=colors.RED)
+            secho(f"Docker process failed, see logs below:\n{e}", fg=colors.RED)
             raise Exit(1)
         except subprocess.TimeoutExpired:
             secho("Docker process timed out.")
             raise Exit(1)
         except json.JSONDecodeError:
-            secho("Unable to decode data from Docker, see logs below:", gf=colors.RED)
+            secho("Unable to decode data from Docker, see logs below:", fg=colors.RED)
             secho(p.stdout)
-            secho(p.stderr, gf=colors.RED)
+            secho(p.stderr, fg=colors.RED)
             raise Exit(1)
         except (KeyError, TypeError):
-            secho("Unable to extract convos and contacts from Docker, see data below", gf=colors.RED)
+            secho(
+                "Unable to extract convos and contacts from Docker, see data below",
+                fg=colors.RED,
+            )
             secho(data)
             raise Exit(1)
     else:
